==> artemis_ui_kit-0.0.2.tar.gz: lib/src/ArtemisButton.dart <==
import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import 'Consts.dart';

class ArtemisButton extends StatelessWidget {
  final String label;
  final Widget? labelWidget;
  final VoidCallback? onPressed;
  final VoidCallback? onLongPress;
  final ButtonStyle? style;
  final Color? backgroundColor;
  final Color? color;
  final bool isLoading;
  final bool bordered;
  final EdgeInsetsGeometry? padding;
  final double radius;

  const ArtemisButton({
    Key? key,
    required this.label,
    this.padding,
    this.labelWidget,
    this.radius=5,
    this.color,
    this.backgroundColor,
    this.onPressed,
    this.onLongPress,
    this.style,
    this.isLoading = false,
    this.bordered = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return bordered
        ? OutlinedButton(
            onLongPress: onLongPress,
            style: style ??
                OutlinedButton.styleFrom(
                  side: BorderSide(color: color ?? ArtemisColors.primary,width: 2),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(radius)
                  ),
                  padding: padding,
                  backgroundColor: backgroundColor ?? ArtemisColors.white2,
                  primary: color ?? ArtemisColors.primary,
                ),
            onPressed: onPressed,
            child: isLoading
                ? SpinKitThreeBounce(
                    color: color ?? ArtemisColors.primary,
                    size: 24,
                  )
                : labelWidget ?? Text(label, style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)))
        : TextButton(
            onLongPress: onLongPress,
            style: style ??
                TextButton.styleFrom(
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(radius)
                  ),
                  padding: padding,
                  backgroundColor: backgroundColor ?? ArtemisColors.white2,
                  primary: color ?? ArtemisColors.primary,
                ),
            onPressed: onPressed,
            child: isLoading
                ? SpinKitThreeBounce(
                    color: color ?? ArtemisColors.primary,
                    size: 24,
                  )
                : labelWidget ?? Text(label, style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)));
  }
}

==> artemis_ui_kit-0.0.5.tar.gz: lib/src/ArtemisButton.dart <==
import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import 'Consts.dart';

class ArtemisButton extends StatelessWidget {
  final String label;
  final Widget? labelWidget;
  final VoidCallback? onPressed;
  final VoidCallback? onLongPress;
  final ButtonStyle? style;
  final Color? backgroundColor;
  final Color? color;
  final bool isLoading;
  final bool bordered;
  final EdgeInsetsGeometry? padding;
  final double radius;

  const ArtemisButton({
    Key? key,
    required this.label,
    this.padding,
    this.labelWidget,
    this.radius = 5,
    this.color,
    this.backgroundColor,
    this.onPressed,
    this.onLongPress,
    this.style,
    this.isLoading = false,
    this.bordered = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return bordered
        ? OutlinedButton(
            onLongPress: onLongPress,
            style: style ??
                OutlinedButton.styleFrom(
                  side: BorderSide(
                      color: color ?? ArtemisColors.primary, width: 2),
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(radius)),
                  padding: padding,
                  backgroundColor: backgroundColor ?? ArtemisColors.white2,
                  primary: color ?? ArtemisColors.primary,
                ),
            onPressed: onPressed,
            child: isLoading
                ? SpinKitThreeBounce(
                    color: color ?? ArtemisColors.primary,
                    size: 24,
                  )
                : labelWidget ??
                    Text(label,
                        style: TextStyle(
                            fontSize: 18, fontWeight: FontWeight.bold)))
        : TextButton(
            onLongPress: onLongPress,
            style: style ??
                TextButton.styleFrom(
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(radius)),
                  padding: padding,
                  backgroundColor: backgroundColor ?? ArtemisColors.white2,
                  primary: color ?? ArtemisColors.primary,
                ),
            onPressed: onPressed,
            child: isLoading
                ? SpinKitThreeBounce(
                    color: color ?? ArtemisColors.primary,
                    size: 24,
                  )
                : labelWidget ??
                    Text(label,
                        style: TextStyle(
                            fontSize: 18, fontWeight: FontWeight.bold)));
  }
}
